var e={d:(t,a)=>{for(var l in a)e.o(a,l)&&!e.o(t,l)&&Object.defineProperty(t,l,{enumerable:!0,get:a[l]})},o:(e,t)=>Object.prototype.hasOwnProperty.call(e,t)},t={};e.d(t,{s:()=>l});let a=!1;const l=function(){(arguments.length>0&&void 0!==arguments[0]?arguments[0]:document).querySelectorAll('input[name*="[global_display]"]:checked').forEach(e=>{n(e)}),a||(document.addEventListener("change",e=>{e.target.name&&e.target.name.includes("[global_display]")&&n(e.target)}),a=!0)},n=e=>{const t=e.value,a=e.name.split("[global_display]")[0];a&&document.querySelectorAll('input[type="radio"][value="g"]').forEach(e=>{e.name.startsWith(a)&&e.setAttribute("data-global-state",t)})},o=t.s;export{o as initDisplaySettings};